==> ecuacion-splib-web-1.73.14-sources.jar: jp/ecuacion/splib/web/bean/RedirectUrlOnSuccessPageBean.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;
import jp.ecuacion.splib.web.enums.LoginStateEnum;

public class RedirectUrlOnSuccessPageBean extends RedirectUrlOnSuccessBean {

  private String page;

  // public RedirectUrlPageBean() {
  // this(new HashMap<>());
  // }

  public RedirectUrlOnSuccessPageBean(String page) {
    this(page, new HashMap<>());
  }

  // public RedirectUrlPageBean(Map<String, String> paramMap) {
  // this(null, true, paramMap);
  // }
  //
  // public RedirectUrlPageBean(String paramKey, String paramValue) {
  // this(null, true, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPageBean(String[][] paramPairs) {
  // this(null, true, paramPairs);
  // }

  public RedirectUrlOnSuccessPageBean(String page, Map<String, String> paramMap) {
    this(page, true, paramMap);
  }

  public RedirectUrlOnSuccessPageBean(String page, String paramKey, String paramValue) {
    this(page, true, paramKey, paramValue);
  }

  public RedirectUrlOnSuccessPageBean(String page, String[][] paramPairs) {
    this(page, true, paramPairs);
  }

  // public RedirectUrlPageBean(boolean needsSuccessMesssage, Map<String, String> paramMap) {
  // this(null, needsSuccessMesssage, paramMap);
  // }
  //
  // public RedirectUrlPageBean(boolean needsSuccessMesssage, String paramKey, String paramValue) {
  // this(null, needsSuccessMesssage, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPageBean(boolean needsSuccessMesssage, String[][] paramPairs) {
  // this(null, needsSuccessMesssage, paramPairs);
  // }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage,
      Map<String, String> paramMap) {
    super(needsSuccessMesssage, paramMap);
    this.page = page;
  }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage, String paramKey,
      String paramValue) {
    super(needsSuccessMesssage, paramKey, paramValue);
    this.page = page;
  }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage,
      String[][] paramPairs) {
    super(needsSuccessMesssage, paramPairs);
    this.page = page;
  }

  public String getPage() {
    return page;
  }

  public void setPage(String page) {
    this.page = page;
  }

  public String getUrl(LoginStateEnum loginState, String functionName) {
    String urlPath =
        "redirect:/" + loginState.getCode() + "/" + functionName + "/" + page + getParamsString();
    return urlPath;
  }
}

==> ecuacion-splib-web-1.75.3-sources.jar: jp/ecuacion/splib/web/bean/RedirectUrlOnSuccessPageBean.java <==
package jp.ecuacion.splib.web.bean;

import java.util.HashMap;
import java.util.Map;
import jp.ecuacion.splib.web.enums.LoginStateEnum;

public class RedirectUrlOnSuccessPageBean extends RedirectUrlOnSuccessBean {

  private String page;

  // public RedirectUrlPageBean() {
  // this(new HashMap<>());
  // }

  public RedirectUrlOnSuccessPageBean(String page) {
    this(page, new HashMap<>());
  }

  // public RedirectUrlPageBean(Map<String, String> paramMap) {
  // this(null, true, paramMap);
  // }
  //
  // public RedirectUrlPageBean(String paramKey, String paramValue) {
  // this(null, true, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPageBean(String[][] paramPairs) {
  // this(null, true, paramPairs);
  // }

  public RedirectUrlOnSuccessPageBean(String page, Map<String, String[]> paramMap) {
    this(page, true, paramMap);
  }

  public RedirectUrlOnSuccessPageBean(String page, String paramKey, String paramValue) {
    this(page, true, paramKey, paramValue);
  }

  public RedirectUrlOnSuccessPageBean(String page, String[][] paramPairs) {
    this(page, true, paramPairs);
  }

  // public RedirectUrlPageBean(boolean needsSuccessMesssage, Map<String, String> paramMap) {
  // this(null, needsSuccessMesssage, paramMap);
  // }
  //
  // public RedirectUrlPageBean(boolean needsSuccessMesssage, String paramKey, String paramValue) {
  // this(null, needsSuccessMesssage, paramKey, paramValue);
  // }
  //
  // public RedirectUrlPageBean(boolean needsSuccessMesssage, String[][] paramPairs) {
  // this(null, needsSuccessMesssage, paramPairs);
  // }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage,
      Map<String, String[]> paramMap) {
    super(needsSuccessMesssage, paramMap);
    this.page = page;
  }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage, String paramKey,
      String paramValue) {
    super(needsSuccessMesssage, paramKey, paramValue);
    this.page = page;
  }

  public RedirectUrlOnSuccessPageBean(String page, boolean needsSuccessMesssage,
      String[][] paramPairs) {
    super(needsSuccessMesssage, paramPairs);
    this.page = page;
  }

  public String getPage() {
    return page;
  }

  public void setPage(String page) {
    this.page = page;
  }

  public String getUrl(LoginStateEnum loginState, String functionName) {
    String urlPath =
        "redirect:/" + loginState.getCode() + "/" + functionName + "/" + page + getParamsString();
    return urlPath;
  }
}
